@@ -1,8 +1,9 @@
-
 import numpy as np
 from random import choice, randrange
+
 # If the code is not Cython-compiled, we need to add some imports.
 from cython import compiled
+
 if not compiled:
     from mazelib.generate.MazeGenAlgo import MazeGenAlgo
 
@@ -19,6 +20,11 @@ class AldousBroder(MazeGenAlgo):
         super(AldousBroder, self).__init__(h, w)
 
     def generate(self):
+        """highest-level method that implements the maze-generating algorithm
+
+        Returns:
+            np.array: returned matrix
+        """
         # create empty grid, with walls
         grid = np.empty((self.H, self.W), dtype=np.int8)
         grid.fill(1)
@@ -42,7 +48,7 @@ class AldousBroder(MazeGenAlgo):
             for nrow, ncol in neighbors:
                 if grid[nrow][ncol] > 0:
                     # open up wall to new neighbor
-                    grid[(nrow + crow)//2][(ncol + ccol)//2] = 0
+                    grid[(nrow + crow) // 2][(ncol + ccol) // 2] = 0
                     # mark neighbor as visited
                     grid[nrow][ncol] = 0
                     # bump the number visited
