@@ -1,8 +1,9 @@
-
 import numpy as np
 from random import randrange
+
 # If the code is not Cython-compiled, we need to add some imports.
 from cython import compiled
+
 if not compiled:
     from mazelib.generate.MazeGenAlgo import MazeGenAlgo
 
@@ -20,6 +21,11 @@ class BacktrackingGenerator(MazeGenAlgo):
         super(BacktrackingGenerator, self).__init__(w, h)
 
     def generate(self):
+        """highest-level method that implements the maze-generating algorithm
+
+        Returns:
+            np.array: returned matrix
+        """
         # create empty grid, with walls
         grid = np.empty((self.H, self.W), dtype=np.int8)
         grid.fill(1)
