@@ -1,15 +1,15 @@
-
 from random import choice, randrange
-from numpy.random import shuffle
 import numpy as np
+
 # If the code is not Cython-compiled, we need to add some imports.
 from cython import compiled
+
 if not compiled:
     from mazelib.generate.MazeGenAlgo import MazeGenAlgo
 
 
 class CellularAutomaton(MazeGenAlgo):
-    """ Cells survive if they have one to four neighbours.
+    """Cells survive if they have one to four neighbours.
     If a cell has exactly three neighbours, it is born.
 
     It is similar to Conway's Game of Life in that patterns
@@ -23,6 +23,11 @@ class CellularAutomaton(MazeGenAlgo):
         self.density = density
 
     def generate(self):
+        """highest-level method that implements the maze-generating algorithm
+
+        Returns:
+            np.array: returned matrix
+        """
         # create empty grid
         grid = np.empty((self.H, self.W), dtype=np.int8)
         grid.fill(0)
@@ -59,7 +64,7 @@ class CellularAutomaton(MazeGenAlgo):
                     neighbors = self._find_neighbors(y, x, grid, False)  # is open
                     if not len(neighbors):
                         continue
-                    r,c = choice(neighbors)
+                    r, c = choice(neighbors)
                     if grid[r, c] == 0:
                         grid[r, c] = 1
                         grid[r + (y - r) // 2, c + (x - c) // 2] = 1
