@@ -1,8 +1,9 @@
-
 from mazelib.generate.MazeGenAlgo import np
 from random import randrange
+
 # If the code is not Cython-compiled, we need to add some imports.
 from cython import compiled
+
 if not compiled:
     from mazelib.generate.MazeGenAlgo import MazeGenAlgo
 
@@ -23,6 +24,11 @@ class Division(MazeGenAlgo):
         super(Division, self).__init__(h, w)
 
     def generate(self):
+        """highest-level method that implements the maze-generating algorithm
+
+        Returns:
+            np.array: returned matrix
+        """
         # create empty grid
         grid = np.empty((self.H, self.W), dtype=np.int8)
         grid.fill(0)
@@ -48,33 +54,35 @@ class Division(MazeGenAlgo):
             if width < height:
                 cut_direction = HORIZONTAL  # with 100% chance
             elif width > height:
-                cut_direction = VERTICAL    # with 100% chance
+                cut_direction = VERTICAL  # with 100% chance
             else:
-                if width == 2: continue
+                if width == 2:
+                    continue
                 cut_direction = randrange(2)
 
-            # make cut
-            #   select cut position (can't be completely on the edge of the region)
+            # MAKE CUT
+            # select cut position (can't be completely on the edge of the region)
             cut_length = (height, width)[(cut_direction + 1) % 2]
-            if cut_length < 3: continue
+            if cut_length < 3:
+                continue
             cut_posi = randrange(1, cut_length, 2)
-            #   select new door position
+            # select new door position
             door_posi = randrange(0, (height, width)[cut_direction], 2)
-            #   add walls to correct places
-            if cut_direction == 0: # vertical
+            # add walls to correct places
+            if cut_direction == 0:  # vertical
                 for row in range(min_y, max_y + 1):
                     grid[row, min_x + cut_posi] = 1
                 grid[min_y + door_posi, min_x + cut_posi] = 0
-            else: # horizontal
+            else:  # horizontal
                 for col in range(min_x, max_x + 1):
                     grid[min_y + cut_posi, col] = 1
                 grid[min_y + cut_posi, min_x + door_posi] = 0
 
-            #   add new regions to stack
+            # add new regions to stack
             if cut_direction == 0:  # vertical
                 region_stack.append(((min_y, min_x), (max_y, min_x + cut_posi - 1)))
                 region_stack.append(((min_y, min_x + cut_posi + 1), (max_y, max_x)))
-            else: # horizontal
+            else:  # horizontal
                 region_stack.append(((min_y, min_x), (min_y + cut_posi - 1, max_x)))
                 region_stack.append(((min_y + cut_posi + 1, min_x), (max_y, max_x)))
 
