@@ -1,8 +1,9 @@
-
 from random import randrange
 import numpy as np
+
 # If the code is not Cython-compiled, we need to add some imports.
 from cython import compiled
+
 if not compiled:
     from mazelib.generate.MazeGenAlgo import MazeGenAlgo
 
@@ -23,6 +24,11 @@ class Prims(MazeGenAlgo):
         super(Prims, self).__init__(h, w)
 
     def generate(self):
+        """highest-level method that implements the maze-generating algorithm
+
+        Returns:
+            np.array: returned matrix
+        """
         # create empty grid
         grid = np.empty((self.H, self.W), dtype=np.int8)
         grid.fill(1)
@@ -44,9 +50,11 @@ class Prims(MazeGenAlgo):
             current_row, current_col = neighbors[nn]
             visited += 1
             grid[current_row][current_col] = 0
-            neighbors = neighbors[:nn] + neighbors[nn + 1:]
+            neighbors = neighbors[:nn] + neighbors[nn + 1 :]
             # connect that neighbor to a random neighbor with grid[posi] == 0
-            nearest_n0, nearest_n1 = self._find_neighbors(current_row, current_col, grid)[0]
+            nearest_n0, nearest_n1 = self._find_neighbors(
+                current_row, current_col, grid
+            )[0]
             grid[(current_row + nearest_n0) // 2][(current_col + nearest_n1) // 2] = 0
 
             # find all unvisited neighbors of current, add them to neighbors
