@@ -1,8 +1,9 @@
-
 from random import randint
 import numpy as np
+
 # If the code is not Cython-compiled, we need to add some imports.
 from cython import compiled
+
 if not compiled:
     from mazelib.generate.MazeGenAlgo import MazeGenAlgo
 
@@ -11,16 +12,15 @@ SPIRAL = 2
 
 
 class TrivialMaze(MazeGenAlgo):
-    """
-    The Algorithm
+    """The Algorithm
 
     This is actually a collection of little tools to make simple,
     unicursal mazes. Currently, there are two trivial mazes available:
     serpentine and spiral.
     """
 
-    def __init__(self, h, w, maze_type='spiral'):
-        if maze_type.lower().strip() == 'serpentine':
+    def __init__(self, h, w, maze_type="spiral"):
+        if maze_type.lower().strip() == "serpentine":
             self.maze_type = SERPENTINE
         else:
             self.maze_type = SPIRAL
@@ -28,6 +28,11 @@ class TrivialMaze(MazeGenAlgo):
         super(TrivialMaze, self).__init__(h, w)
 
     def generate(self):
+        """highest-level method that implements the maze-generating algorithm
+
+        Returns:
+            np.array: returned matrix
+        """
         # create empty grid
         grid = np.empty((self.H, self.W), dtype=np.int8)
         grid.fill(1)
@@ -38,8 +43,13 @@ class TrivialMaze(MazeGenAlgo):
             return self._generate_spiral_maze(grid)
 
     def _generate_serpentine_maze(self, grid):
-        """ Create a simple maze that snakes around the grid.
+        """Create a simple maze that snakes around the grid.
         This is a unicursal maze (with no dead ends).
+
+        Args:
+            grid (np.array): maze array
+        Returns:
+            np.array: update maze array
         """
         vertical_skew = randint(0, 1)
         height = grid.shape[0]
@@ -67,8 +77,13 @@ class TrivialMaze(MazeGenAlgo):
         return grid
 
     def _generate_spiral_maze(self, grid):
-        """ Create a simple maze that has a spiral path from
+        """Create a simple maze that has a spiral path from
         start to end. This is a unicursal maze (with no dead ends).
+
+        Args:
+            grid (np.array): maze array
+        Returns:
+            np.array: update maze array
         """
         clockwise = randint(0, 1)
         # define the directions you will turn
@@ -90,16 +105,28 @@ class TrivialMaze(MazeGenAlgo):
             elif len(ns) == 0:
                 break
             else:
-                next_dir = (next_dir + 1) %4
+                next_dir = (next_dir + 1) % 4
 
         return grid
 
     def _midpoint(self, a, b):
-        """ Find the wall cell between to passage cells """
+        """Find the wall cell between to passage cells
+
+        Args:
+            a (tuple): first cell position
+            b (tuple): second cell position
+        Returns:
+            tuple: cell position at the half-way point between the other two
+        """
         return (a[0] + b[0]) // 2, (a[1] + b[1]) // 2
 
     def _move(self, start, direction):
-        """ Convolve a position tuple with a direction tuple to
-        generate a new position.
+        """Convolve a position tuple with a direction tuple to generate a new position.
+
+        Args:
+            start (tuple): first cell position
+            direction (tuple): direction to travel from start
+        Returns:
+            tuple: end result of start position plus direction vector
         """
         return (start[0] + direction[0], start[1] + direction[1])
