@@ -1,12 +1,13 @@
-from random import choice, shuffle
 # If the code is not Cython-compiled, we need to add some imports.
 from cython import compiled
+
 if not compiled:
     from mazelib.solve.MazeSolveAlgo import MazeSolveAlgo
 
 
 class ShortestPaths(MazeSolveAlgo):
-    """
+    """The Algorithm
+
     1) create a solution for each starting position
     2) loop through each solution, and find the neighbors of the last element
     3) The first solution to reach the end wins.
@@ -17,6 +18,11 @@ class ShortestPaths(MazeSolveAlgo):
     """
 
     def _solve(self):
+        """bredth-first search solutions to the maze
+
+        Returns:
+            list: valid maze solutions
+        """
         # determine if edge or body entrances
         self.start_edge = self._on_edge(self.start)
         self.end_edge = self._on_edge(self.end)
@@ -28,7 +34,7 @@ class ShortestPaths(MazeSolveAlgo):
 
         # find the starting positions
         start_posis = self._find_unblocked_neighbors(start)
-        assert len(start_posis) > 0, 'Input maze is invalid.'
+        assert len(start_posis) > 0, "Input maze is invalid."
 
         # 1) create a solution for each starting position
         solutions = []
@@ -48,11 +54,14 @@ class ShortestPaths(MazeSolveAlgo):
                 elif self._within_one(solutions[s][-1], self.end):
                     # stop all solutions that have reached the end
                     solutions[s].append(None)
-                elif solutions[s][-1] != None:
+                elif solutions[s][-1] is not None:
                     # continue with all un-stopped solutions
                     if len(solutions[s]) > 1:
                         # check to see if you've gone past the endpoint
-                        if self._midpoint(solutions[s][-1], solutions[s][-2]) == self.end:
+                        if (
+                            self._midpoint(solutions[s][-1], solutions[s][-2])
+                            == self.end
+                        ):
                             solutions[s].append(None)
                             continue
 
@@ -75,21 +84,28 @@ class ShortestPaths(MazeSolveAlgo):
                         solutions[s].append(self._midpoint(ns[0], solutions[s][-1]))
                         solutions[s].append(ns[0])
 
-            # 3) a solution reaches the end or a dead end when we mark it by appending a None. 
-            num_unfinished = sum(map(lambda sol: 0 if sol[-1] is None else 1 , solutions))
+            # 3) a solution reaches the end or a dead end when we mark it by appending a None.
+            num_unfinished = sum(
+                map(lambda sol: 0 if sol[-1] is None else 1, solutions)
+            )
 
         # 4) clean-up solutions
         solutions = self._clean_up(solutions)
 
-        assert (len(solutions) > 0 and len(solutions[0]) > 0), 'No valid solutions found.'
+        assert len(solutions) > 0 and len(solutions[0]) > 0, "No valid solutions found."
 
         return solutions
 
     def _clean_up(self, solutions):
-        """ Cleaning up the solutions in three stages:
+        """Cleaning up the solutions in three stages:
         1) remove incomplete solutions
         2) remove duplicate solutions
         3) order the solutions by length (short to long)
+
+        Args:
+            solutions (list): collection of maze solutions
+        Returns:
+            list: cleaner collection of solutions
         """
         # 1) remove incomplete solutions
         new_solutions = []
@@ -119,5 +135,11 @@ class ShortestPaths(MazeSolveAlgo):
         return sorted(solutions, key=len)
 
     def _remove_duplicate_sols(self, sols):
-        """ Remove duplicate solutions using subsetting """
+        """Remove duplicate solutions using subsetting
+
+        Args:
+            solutions (list): collection of maze solutions
+        Returns:
+            list: collection of unique maze solutions
+        """
         return [list(s) for s in set(map(tuple, sols))]
